package gregapi.network;

import gregapi.block.IBlockSyncData;
import gregapi.util.UT;
import net.minecraft.block.Block;
import net.minecraft.world.IBlockAccess;

import com.google.common.io.ByteArrayDataInput;
import com.google.common.io.ByteArrayDataOutput;

/**
 * @author Gregorius Techneticies
 * 
 * Transmits the extended Data of a Block.
 */
public class PacketSyncDataByteArray extends PacketCoordinates {
	public byte[] mData = new byte[0];
	
	public PacketSyncDataByteArray(int aDecoderType) {
		super(aDecoderType);
	}
	
	/** aData is limited to length = 256 */
	public PacketSyncDataByteArray(int aX, int aY, int aZ, byte... aData) {
		super(aX, aY, aZ);
		mData = aData;
	}
	
	@Override
	public byte getPacketIDOffset() {
		return -56;
	}
	
	@Override
	public ByteArrayDataOutput encode2(ByteArrayDataOutput aData) {
		aData.writeByte(mData.length);
		aData.write(mData);
		return aData;
	}
	
	@Override
	public PacketCoordinates decode2(int aX, int aY, int aZ, ByteArrayDataInput aData) {
		byte[] tData = new byte[UT.Code.unsignB(aData.readByte())];
		aData.readFully(tData);
		return new PacketSyncDataByteArray(aX, aY, aZ, tData);
	}
	
	@Override
	public void process(IBlockAccess aWorld, INetworkHandler aNetworkHandler) {
		if (aWorld != null) {
			Block tBlock = aWorld.getBlock(mX, mY, mZ);
			if (tBlock instanceof IBlockSyncData) ((IBlockSyncData)tBlock).receiveDataByteArray(aWorld, mX, mY, mZ, mData, aNetworkHandler);
		}
	}
}